@@ -1,4 +1,4 @@
-pdfNCA = function(fileName="Temp-NCA.pdf", concData, key = "Subject", colTime="Time", colConc="conc", dose=0, adm="Extravascular", dur=0, doseUnit="mg", timeUnit="h", concUnit="ug/L", down="Linear", R2ADJ=0, MW=0)
+pdfNCA = function(fileName="Temp-NCA.pdf", concData, key = "Subject", colTime="Time", colConc="conc", dose=0, adm="Extravascular", dur=0, doseUnit="mg", timeUnit="h", concUnit="ug/L", down="Linear", R2ADJ=0, MW=0, iAUC)
 {
   defPar = par(no.readonly=TRUE)
 
@@ -6,9 +6,9 @@ pdfNCA = function(fileName="Temp-NCA.pdf", concData, key = "Subject", colTime="T
   AddPage()
   Text1(1, 1, "Individual Noncompartmental Analysis Result", Cex=1.2)
 
-  maxx = max(concData[,colTime])
-  maxy = max(concData[,colConc])
-  miny = min(concData[concData[,colConc] > 0, colConc])
+  maxx = max(concData[,colTime], na.rm=TRUE)
+  maxy = max(concData[,colConc], na.rm=TRUE)
+  miny = min(concData[concData[,colConc]>0, colConc], na.rm=TRUE)
 
   nKey = length(key)
   IDs = unique(as.data.frame(concData[,key], ncol=nKey))
@@ -35,7 +35,7 @@ pdfNCA = function(fileName="Temp-NCA.pdf", concData, key = "Subject", colTime="T
     if (nrow(tData) > 0) {
       x = tData[,colTime]
       y = tData[,colConc]
-      tabRes = sNCA(x, y, dose=dose[i], adm=adm, dur=dur, doseUnit=doseUnit, timeUnit=timeUnit, concUnit=concUnit, down=down, R2ADJ=R2ADJ, MW=MW)
+      tabRes = sNCA(x, y, dose=dose[i], adm=adm, dur=dur, doseUnit=doseUnit, timeUnit=timeUnit, concUnit=concUnit, down=down, R2ADJ=R2ADJ, MW=MW, iAUC=iAUC)
       UsedPoints = attr(tabRes, "UsedPoints")
       txtRes = Res2Txt(tabRes, x, y, dose=dose[i], adm=adm, dur=dur, doseUnit=doseUnit, down=down)
       Res = c(Res, txtRes)
@@ -59,8 +59,8 @@ pdfNCA = function(fileName="Temp-NCA.pdf", concData, key = "Subject", colTime="T
 
       screen(ScrNo[3])
       par(oma=c(1,1,1,1), mar=c(4,4,3,1), adj=0.5)
-      x0 = x[y > 0]
-      y0 = y[y > 0]
+      x0 = x[!is.na(y) & y > 0]
+      y0 = y[!is.na(y) & y > 0]
       plot(x0, log10(y0), type="b", cex=0.7, xlim=c(0, maxx), ylim=c(log10(miny), log10(maxy)), yaxt="n", xlab=paste0("Time (", timeUnit, ")"), ylab=paste0("Concentration (log interval) (", concUnit, ")"))
       points(x[UsedPoints], log10(y[UsedPoints]), pch=16)
       yticks = seq(round(min(log10(y0))), ceiling(max(log10(y0))))
